import { ElementStyles } from '@microsoft/fast-element';
import { FASTElement } from '@microsoft/fast-element';
import { NetworkMonitor } from '@genesislcap/foundation-comms';
import { SystemHealthStatus } from '@genesislcap/foundation-comms';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * @public
 */
export declare const foundationSystemHealthAlertsServer: ElementStyles;

/**
 * @public
 */
export declare const foundationSystemHealthAlertsServiceStyles: ElementStyles;

/**
 * @public
 */
export declare const getPrefixedSystemHealthAlertsServer: (prefix: any) => ViewTemplate<SystemHealthAlertsServer, any>;

/**
 * @public
 */
export declare const getPrefixedSystemHealthAlertsService: (designSystemPrefix: string, templates?: ServiceStatusGetTemplateParmas) => ViewTemplate<SystemHealthAlertsService, any>;

/**
 * Configuration options for service status, including behavior around automatic closure and timeouts.
 * @public
 */
export declare interface ServerStatusConfig {
    autoClose: boolean;
    closeTimeout: number;
}

/**
 * Represents server status message item.
 * @public
 */
export declare interface ServerStatusMessageItem {
    title: string;
    content: string;
}

/**
 * Configuration options for service status, including behavior around automatic closure and timeouts.
 * @public
 */
export declare interface ServicesStatusConfig {
    autoClose: boolean;
    closeTimeout: number;
    maxMessages: number;
}

/**
 * Parameters for template functions used in service status messaging, providing hooks for restoration and failure handling.
 * @public
 */
export declare interface ServiceStatusGetTemplateParmas {
    restored: (prefix: string, item: SystemHealthAlertsServiceItem) => any;
    failed: (prefix: string, item: SystemHealthAlertsServiceItem) => any;
}

/**
 * @internal
 * Default timeout for closing message
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVER_CLOSE_TIMEOUT = 10000;

/**
 * @public
 * Default server status.
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVER_DEFAULT_STATUS: "unknown";

/**
 * @public
 * Events names
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVER_EVENTS_NAMES: {
    readonly CHANGED: "changed";
    readonly UP: "up";
    readonly DOWN: "down";
    readonly UNKNOWN: "unknown";
    readonly CLOSE: "alert-close";
};

/**
 * @internal
 * Prefix for logger
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVER_LOGGER_PREFIX = "SERVICE - ";

/**
 * @public
 * Available status of server.
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVER_STATUSES: {
    readonly UNKNOWN: "unknown";
    readonly UP: "restored";
    readonly DOWN: "failed";
};

/**
 * @internal
 * Default timeout for closing message
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVICE_CLOSE_TIMEOUT = 10000;

/**
 * @public
 * Events names
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVICE_EVENTS_NAMES: {
    readonly CHANGED: "services-changed";
    readonly FAIL: "service-fail";
    readonly RESTORED: "service-restored";
    readonly CLOSE_MESSAGE: "dismiss";
    readonly AUTO_CLOSE_MESSAGE: "autoDismiss";
};

/**
 * @internal
 * Prefix for logger
 */
export declare const SYSTEM_HEALTH_ALERTS_SERVICE_LOGGER_PREFIX = "SERVICE - ";

/**
 * The `SystemHealthAlertsBase` component is designed to monitor and display the status of server in real-time.
 *
 * @alpha
 */
declare class SystemHealthAlertsBase extends FASTElement {
    protected monitor: NetworkMonitor;
    systemStatus: SystemHealthStatus;
    protected rootEventsListeners: SystemHealthAlertsEventListeners;
    connectedCallback(): void;
    handleChange(): void;
    disconnectedCallback(): void;
    startMonitoring(): Promise<void>;
    stopMonitoring(): void;
}

/**
 * System health alerts event listeners
 * @internal
 */
declare type SystemHealthAlertsEventListeners = {
    key: string;
    action: (event: Event) => void;
}[];

/**
 * The `SystemHealthAlertsServer` component is designed to monitor and display the status of server in real-time.
 *
 * @alpha
 */
export declare class SystemHealthAlertsServer extends SystemHealthAlertsBase {
    autoClose: ServerStatusConfig['autoClose'];
    closeTimeout: ServerStatusConfig['closeTimeout'];
    displayOnChange: boolean;
    titleRestored: string;
    messageRestored: string;
    titleFailed: string;
    messageFailed: string;
    currentServerStatus: SystemHealthAlertsServerAvailableStatus;
    currentServerStatusChanged(oldServerStatus: SystemHealthAlertsServerAvailableStatus, newServerStatus: SystemHealthAlertsServerAvailableStatus): void;
    display: boolean;
    systemStatusChanged(ignore: any, newStatus: any): void;
    constructor();
    closeHandler: (event: any) => void;
    private setServerStatus;
    getCurrentMessage(): ServerStatusMessageItem | undefined;
}

/**
 * Represents the available status of server.
 * @public
 */
export declare type SystemHealthAlertsServerAvailableStatus = (typeof SYSTEM_HEALTH_ALERTS_SERVER_STATUSES)[keyof typeof SYSTEM_HEALTH_ALERTS_SERVER_STATUSES];

/**
 * The `SystemHealthAlertsService` component is designed to monitor and display the status of various services in real-time.
 * It leverages a connection to a backend datasource to receive updates about services status
 * and displays these updates to the user.
 *
 * @alpha
 */
export declare class SystemHealthAlertsService extends SystemHealthAlertsBase {
    closeTimeout: ServicesStatusConfig['closeTimeout'];
    autoClose: ServicesStatusConfig['autoClose'];
    maxMessages: ServicesStatusConfig['maxMessages'];
    maxMessagesChanged(): void;
    messageRestored: string;
    messageFailed: string;
    titleRestored: string;
    titleFailed: string;
    allMessages: SystemHealthAlertsServiceItem[];
    allMessagesChanged(ignore: any, currentMessages: any): void;
    displayMessages: SystemHealthAlertsServiceItem[];
    systemStatusServices: SystemHealthAlertsServiceItem[];
    systemStatusServicesChanged(oldServices: SystemHealthAlertsServiceItem[], newServices: SystemHealthAlertsServiceItem[]): void;
    systemStatusChanged(ignore: any, newStatus: any): void;
    private updateDisplayMessages;
    private prepareServiceItem;
    private closeMessageHandler;
    emitCloseMessage(target: any, identifier: any): void;
    private replaceTextPlaceholders;
    getTextHelper: (textType: SystemHealthAlertsServiceHelperText, type: SystemHealthAlertsServiceItemState, item: SystemHealthAlertsServiceItem) => string;
}

/**
 * Type helper for the service status helper text generation.
 * @internal
 */
export declare type SystemHealthAlertsServiceHelperText = 'title' | 'message';

/**
 * Represents an individual service with basic information necessary for status tracking.
 * @public
 */
export declare interface SystemHealthAlertsServiceItem {
    tag: string;
    name: string;
    isConnected: boolean;
}

/**
 * Represents the available types of service status messages.
 * @public
 */
export declare type SystemHealthAlertsServiceItemState = 'restored' | 'failed';

/**
 * Represents the server item with basic information necessary for status tracking.
 * @internal
 */
export declare interface SystemHealthAlertsServiceSystemStatusItem {
    isConnected: boolean;
    lastError: number;
    lastUpdated: number;
    name: string;
    sourceRef: string[];
}

/**
 * ZeroSystemHealthAlertsServer.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroSystemHealthAlertsServer } from '@genesislcap/foundation-system-health-alerts';
 * ...
 * ZeroSystemHealthAlertsServer
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroSystemHealthAlertsServer } = await import('@genesislcap/foundation-system-health-alerts');
 *   return ZeroSystemHealthAlertsServer;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroSystemHealthAlertsServer extends SystemHealthAlertsServer {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}

/**
 * ZeroSystemHealthAlertsService.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system.
 *
 * @example
 * ```ts
 * import { ZeroSystemHealthAlertsService } from '@genesislcap/foundation-system-health-alerts';
 * ...
 * ZeroSystemHealthAlertsService
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroSystemHealthAlertsService } = await import('@genesislcap/foundation-system-health-alerts');
 *   return ZeroSystemHealthAlertsService;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroSystemHealthAlertsService extends SystemHealthAlertsService {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}

export { }
